@@ -46,7 +46,7 @@ DEFAULT_SPECD_PATH = os.path.join(
     os.path.dirname(__file__), "../../gosdk/specs/"
 )
 
-VERSION = "0.9.19"
+VERSION = "0.9.20"
 COPYRIGHT = "Copyright: GenomOncology, LLC"
 
 
@@ -237,15 +237,13 @@ def aggregate_cosmic(state, cosmic_tsv_path):
 
 
 @gocli.command()
-@click.argument(
-    "record_type",
-    type=click.Choice(['cnv', 'fusion']),
-)
+@click.argument("record_type", type=click.Choice(["cnv", "fusion"]))
 @options.build_option
 @options.pass_state
 def aggregate_non_snv_cosmic(state, record_type):
     return [sources.AggregatedCOSMICNonSNVSources(record_type=record_type)]
 
+
 @gocli.command()
 @click.option(
     "--column",
@@ -706,10 +704,21 @@ def match_therapies(state, diseases):
 @click.option(
     "--cnv_match_tolerance", "-cmt", help="CNV match tolerance", default=0.33
 )
+@click.option(
+    "--keep_ref_unknown_calls",
+    "-k",
+    "keep_ref_unknown_calls",
+    help="Include homozygous reference and unknown calls.",
+    is_flag=True,
+)
 @options.pass_state
 @options.build_option
 def sv_match(
-    state, delete_if_exists, region_match_tolerance, cnv_match_tolerance
+    state,
+    delete_if_exists,
+    region_match_tolerance,
+    cnv_match_tolerance,
+    keep_ref_unknown_calls,
 ):
     """Calls the annotations sv matching endpoint."""
 
@@ -717,6 +726,11 @@ def sv_match(
     sdk_function = kms.annotations.sync_annotate_sv_match
 
     return [
+        filter(
+            filter_out_ref_unknown(
+                keep_ref_unknown_calls=keep_ref_unknown_calls
+            )
+        ),
         filter(is_not_skipped_call),
         partition_all(99_999_999),
         create_function(
