@@ -201,10 +201,19 @@ def sync_annotate_sv_match(
     region_match_tolerance=0.5,
     cnv_match_tolerance=0.33,
 ):
+    SV_MUTATION_TYPES = ["INS", "INV", "DEL", "DUP", "CNV", "BND"]
     batch = []
     seen_bnd_ids = []
     for record in calls:
         if record["__type__"] != "HEADER":
+            if record.get("mutation_type") not in SV_MUTATION_TYPES:
+                msg = (
+                    f"unknown SVTYPE of '{record.get('mutation_type', None)}'\n"
+                    f"\t(expected valid SVTYPEs {SV_MUTATION_TYPES})\n"
+                    "Annotations SV Match Process Terminated"
+                )
+                raise ValueError(msg)
+
             if record["mutation_type"] == "BND":
                 if record["id"] not in seen_bnd_ids:
                     batch.append(parse_bnd_sv_hashes(record, calls))
