@@ -7,6 +7,7 @@ from .aggregated import (
     AggregatedCOSMICSources,
     AggregatedFileSource,
     AggregatedOmimFileSource,
+    AggregatedCOSMICNonSNVSources
 )
 from .maf import MAFSource
 from .xml import XMLSource
@@ -23,6 +24,7 @@ __all__ = (
     "CollectFilePathsSource",
     "ExcelSource",
     "AggregatedCOSMICSources",
+    "AggregatedCOSMICNonSNVSources",
     "AggregatedFileSource",
     "MAFSource",
     "XMLSource",
