@@ -30,8 +30,8 @@ class XMLSource:
             exit()
 
     def determine_xml_source(self, data_set_name, file_path):
-        return (
-            ClinvarXMLSource(file_path)
-            if data_set_name == "clinvar_xml"
-            else None
-        )
+        if data_set_name == "clinvar_xml":
+            return ClinvarXMLSource(file_path)
+        elif data_set_name == "clinvar_grch38_xml":
+            return ClinvarXMLSource(file_path, is_grch38=True)
+        return None
