@@ -13,6 +13,7 @@ from . import (
     baylor_decipher,
     evs,
     cosmic,
+    cosmic_non_snv,
     hpo,
     omim,
     genie_maf,
@@ -44,6 +45,7 @@ __all__ = (
     "splicing",
     "evs",
     "cosmic",
+    "cosmic_non_snv",
     "baylor_decipher",
     "hpo",
     "omim",
