@@ -16,7 +16,14 @@ NAME_MAPPING = {
     "gene": "Gene name",
     "CNT__int": "CNT",
     "tissues__mstring": "TISSUES",
+    "tissue_cnt__mstring": "TISSUES",
     "tissue_frequency__mstring": "TISSUES_FREQ",
+    "tissue_subtype_cnt__mstring": "TISSUES_SUBTYPE",
+    "tissue_subtype_frequency__mstring": "TISSUES_SUBTYPE_FREQ",
+    "histology_cnt__mstring": "HISTOLOGY",
+    "histology_frequency__mstring": "HISTOLOGY_FREQ",
+    "histology_subtype_cnt__mstring": "HISTOLOGY_SUBTYPE",
+    "histology_subtype_frequency__mstring": "HISTOLOGY_SUBTYPE_FREQ",
     "resistance_mutation__mstring": "RESISTANCE_MUTATION",
     "genomicID__string": "ID",
     "ID__mstring": "MUTATION_ID",
@@ -59,9 +66,9 @@ def get_keys(x, field):
     return list(x.get(field, {}).keys())
 
 
-def process_tissue_frequency(x):
+def process_frequency_and_counts(x, field):
     freq_results = []
-    freq_info = x.get("tissue_frequency__mstring")
+    freq_info = x.get(field)
     for tissue, freq in freq_info.items():
         freq_results.append(f"{tissue}={freq}")
     return freq_results
@@ -109,7 +116,48 @@ register(
             x, "tissues__mstring", get_keys(x, "tissues__mstring")
         ),
         lambda x: assoc(
-            x, "tissue_frequency__mstring", process_tissue_frequency(x)
+            x,
+            "tissue_cnt__mstring",
+            process_frequency_and_counts(x, "tissue_cnt__mstring"),
+        ),
+        lambda x: assoc(
+            x,
+            "tissue_frequency__mstring",
+            process_frequency_and_counts(x, "tissue_frequency__mstring"),
+        ),
+        lambda x: assoc(
+            x,
+            "tissue_subtype_cnt__mstring",
+            process_frequency_and_counts(x, "tissue_subtype_cnt__mstring"),
+        ),
+        lambda x: assoc(
+            x,
+            "tissue_subtype_frequency__mstring",
+            process_frequency_and_counts(
+                x, "tissue_subtype_frequency__mstring"
+            ),
+        ),
+        lambda x: assoc(
+            x,
+            "histology_cnt__mstring",
+            process_frequency_and_counts(x, "histology_cnt__mstring"),
+        ),
+        lambda x: assoc(
+            x,
+            "histology_frequency__mstring",
+            process_frequency_and_counts(x, "histology_frequency__mstring"),
+        ),
+        lambda x: assoc(
+            x,
+            "histology_subtype_cnt__mstring",
+            process_frequency_and_counts(x, "histology_subtype_cnt__mstring"),
+        ),
+        lambda x: assoc(
+            x,
+            "histology_subtype_frequency__mstring",
+            process_frequency_and_counts(
+                x, "histology_subtype_frequency__mstring"
+            ),
         ),
         lambda x: remove_start_field(x),
         lambda x: assoc(x, "csra", handle_hgvs_g(x)),
