@@ -6,7 +6,7 @@ import re
 
 NAME_MAPPING = {
     "gene": "gene",
-    "gene_mim__mstring": "MIM Number",
+    "gene_mim": "MIM Number",
     "phenotype__mstring": "phenotype",
     "phenotype_mim__mstring": "phenotype_mim",
     "inheritance__mstring": "inheritance",
