@@ -48,8 +48,9 @@ def iterate_vcf_calls(
 
         for sample in samples:
             # if GT not specified, then assume single alt
-            allele_indices, zyg, sample_is_ref_unknown = \
-                get_allele_indices_and_zyg(sample)
+            allele_indices, zyg, is_ref_unknown = get_allele_indices_and_zyg(
+                sample
+            )
 
             for allele_index in allele_indices:
                 alt = get_alt(record, allele_index)
@@ -60,7 +61,7 @@ def iterate_vcf_calls(
                     yield create_skipped_call_dict(
                         record, sample, alt, info.get("GT")
                     )
-                elif keep_ref_unknown_calls or not sample_is_ref_unknown:
+                elif keep_ref_unknown_calls or not is_ref_unknown:
                     vaf_dict = (
                         vaf_map(info, allele_index, alt) if vaf_map else {}
                     )
@@ -132,7 +133,7 @@ def iter_attrs(obj, include_private=False, type_filter=None):
         if include_private or not attr_name.startswith("_"):
             attr_value = getattr(obj, attr_name)
             if not type_filter or isinstance(attr_value, type_filter):
-                yield (attr_name, attr_value)
+                yield attr_name, attr_value
 
 
 def create_meta_dict(items, meta_types=(int, str, bool, float)):
